@@ -1,5 +1,5 @@
 #  GNU Mailutils -- a suite of utilities for electronic mail
-#  Copyright (C) 2009-2012, 2014-2016 Free Software Foundation, Inc.
+#  Copyright (C) 2009-2020 Free Software Foundation, Inc.
 #
 #  GNU Mailutils is free software; you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -19,7 +19,7 @@ from mailutils import stream
 from mailutils import filter
 
 if len (sys.argv) != 3:
-    print "usage: %s from-code to-code" % sys.argv[0]
+    print("usage: %s from-code to-code" % sys.argv[0])
     sys.exit (0)
 
 sti = stream.StdioStream (stream.MU_STDIN_FD)
