@@ -1,5 +1,5 @@
 #  GNU Mailutils -- a suite of utilities for electronic mail
-#  Copyright (C) 2009-2012, 2014-2016 Free Software Foundation, Inc.
+#  Copyright (C) 2009-2020 Free Software Foundation, Inc.
 #
 #  GNU Mailutils is free software; you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -26,12 +26,12 @@ def ls_folders (fname, ref, pattern, level):
 
         list = fld.list (ref, pattern, level)
         for f in list:
-            print f
-        print "Number of folders: %d" % len (list)
+            print(f)
+        print("Number of folders: %d" % len (list))
 
         fld.close ()
-    except Error, e:
-        print e
+    except Error as e:
+        print(e)
 
 if __name__ == '__main__':
     pattern = "*"
@@ -54,7 +54,7 @@ if __name__ == '__main__':
         ref = None
         fname = sys.argv[1]
     else:
-        print "usage: lsf folder [ref] [pattern] [recursion-level]"
+        print("usage: lsf folder [ref] [pattern] [recursion-level]")
         sys.exit (0)
 
     registrar.register_format ()
