@@ -1,6 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999, 2001, 2003, 2005-2012, 2014-2017 Free Software
-   Foundation, Inc.
+   Copyright (C) 1999-2020 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -58,7 +57,7 @@ imap4d_select0 (struct imap4d_command *command, const char *mboxname,
       imap4d_sync ();
     }
 
-  if (strcmp (mboxname, "INBOX") == 0)
+  if (mu_c_strcasecmp (mboxname, "INBOX") == 0)
     flags |= MU_STREAM_CREAT;
   mailbox_name = namespace_get_name (mboxname, &record, NULL);
 
