@@ -2217,6 +2217,7 @@ mu_cfg_tree_postprocess (mu_cfg_tree_t *tree, struct mu_cfg_parse_hints *hints)
 	  mu_iterator_ctl (itr, mu_itrctl_delete, NULL);
 	}
     }
+  mu_iterator_destroy (&itr);
   return 0;
 }
 
@@ -2276,6 +2277,7 @@ mu_cfg_destroy_tree (mu_cfg_tree_t **ptree)
       mu_cfg_tree_t *tree = *ptree;
       mu_list_destroy (&tree->nodes);
       mu_opool_destroy (&tree->pool);
+      free (tree);
       *ptree = NULL;
     }
 }
@@ -2884,6 +2886,7 @@ split_cfg_path (const char *path, int *pargc, char ***pargv)
 	{
 	  mu_error (_("cannot split line `%s': %s"), path,
 		    mu_wordsplit_strerror (&ws));
+	  mu_wordsplit_free (&ws);
 	  return errno;
 	}
       argc = ws.ws_wordc;
