@@ -1104,14 +1104,18 @@ mu_stream_close (mu_stream_t stream)
   if (!(stream->flags & _MU_STR_OPEN))
     return MU_ERR_NOT_OPEN;
   
-  mu_stream_flush (stream);
-  /* Do close the stream only if it is not used by anyone else */
-  if (stream->ref_count > 1)
-    return 0;
-  _stream_event (stream, _MU_STR_EVENT_CLOSE, 0, NULL);
-  if (stream->close)
-    rc = stream->close (stream);
-  _stream_clrflag (stream, _MU_STR_OPEN);
+  rc = mu_stream_flush (stream);
+  if (rc == 0)
+    {
+      /* Do close the stream only if it is not used by anyone else */
+      if (stream->ref_count > 1)
+	return 0;
+      _stream_event (stream, _MU_STR_EVENT_CLOSE, 0, NULL);
+      if (stream->close)
+	rc = stream->close (stream);
+      if (rc == 0)
+	_stream_clrflag (stream, _MU_STR_OPEN);
+    }
   return rc;
 }
 
@@ -1133,8 +1137,12 @@ mu_stream_size (mu_stream_t stream, mu_off_t *psize)
   rc = stream->size (stream, &size);
   if (rc == 0)
     {
-      if (stream->buftype != mu_buffer_none && stream->offset == size)
-	size += stream->level;
+      if (stream->buftype != mu_buffer_none)
+	{
+	  size_t n = stream->offset + stream->level;
+	  if (n > size)
+	    size = n;
+	}
       *psize = size;
     }
   return mu_stream_seterr (stream, rc, rc != 0);
