@@ -1,6 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2004-2005, 2007, 2010-2012, 2014-2017 Free Software
-   Foundation, Inc.
+   Copyright (C) 2004-2020 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -36,23 +35,27 @@
 #include <mailutils/url.h>
 #include <mailutils/sys/amd.h>
 
+/* Check if SUBDIR exists in directory NAME.  Return 0 on success,
+   or error code on failure. */
 static int
-dir_exists (const char *name, const char *suf)
+subdir_exists (const char *name, int subdir)
 {
   struct stat st;
-  int rc;
   char *s;
 
-  rc = maildir_mkfilename (name, suf, NULL, &s);
-  if (rc)
-    return 0;/* FIXME: error message */
+  s = mu_make_file_name (name, mu_maildir_subdir_name (subdir));
+  if (!s)
+    return ENOMEM; /* FIXME: error message */
   
   if (stat (s, &st) < 0)
-    return 0;
+    return errno;
 
   free (s);
   
-  return S_ISDIR (st.st_mode);
+  if (!S_ISDIR (st.st_mode))
+    return ENOTDIR;
+
+  return 0;
 }
 
 static int
@@ -87,9 +90,9 @@ _maildir_is_scheme (mu_record_t record, mu_url_t url, int flags)
 	  rc |= MU_FOLDER_ATTRIBUTE_DIRECTORY;
       
 	  if ((flags & MU_FOLDER_ATTRIBUTE_FILE)
-	      && dir_exists (path, TMPSUF)
-	      && dir_exists (path, CURSUF)
-	      && dir_exists (path, NEWSUF))
+	      && subdir_exists (path, SUB_TMP) == 0
+	      && subdir_exists (path, SUB_CUR) == 0
+	      && subdir_exists (path, SUB_NEW) == 0)
 	    rc |= MU_FOLDER_ATTRIBUTE_FILE;
 	}
     }
@@ -99,11 +102,7 @@ _maildir_is_scheme (mu_record_t record, mu_url_t url, int flags)
 static int
 _maildir_list_p (mu_record_t record, const char *name, int flags MU_ARG_UNUSED)
 {
-  return strcmp (name, TMPSUF)
-    && strcmp (name, CURSUF) 
-    && strcmp (name, NEWSUF)
-    && !((strlen (name) > 3) &&
-	 (memcmp (name, ".mh", 3) == 0 || memcmp (name, ".mu", 3) == 0));
+  return !mu_maildir_reserved_name (name);
 }
 
 static struct _mu_record _maildir_record =
