@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2004-2019 Free Software Foundation, Inc.
+   Copyright (C) 2004-2020 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -16,9 +16,15 @@
    <http://www.gnu.org/licenses/>. */
 
 #define PERMS 0700
-#define TMPSUF "tmp"
-#define CURSUF "cur"
-#define NEWSUF "new"
 
-int maildir_mkfilename (const char *dir, const char *suffix,
-			const char *name, char **retname);
+/* Subdirectories in maildir folder */
+enum
+  {
+    SUB_CUR,
+    SUB_NEW,
+    SUB_TMP,
+  };
+
+char const *mu_maildir_subdir_name (int subdir);
+int mu_maildir_reserved_name (char const *name);
+
